@@ -1,7 +1,28 @@
 import sys
 import PyColors
 from . import environshell
-from . import dev
+
+
+def create_dependencies(envname):
+    os.mkdir(f"{envname}")
+    makefile("settings.json", 'w', contents=contents)
+    os.mkdir(f'{envname}_panel')
+    makefile("host.py", 'w', contents=hostpy)
+    makefile("panel/base.html", contents=html)
+    makefile(browsepy)
+    os.mkdir('UploadConfigs')
+    makefile("UploadConfigs/note.txt", "the current folder is for")
+
+
+def browse(filename):
+    for file in os.listdir('./'):
+        if file == os.path.isfile():
+            print(True)
+            print("found file")
+            with open(file) as f:
+                data = f.read()
+            print(f"""Read file and found:\t\n{data } """)
+
 
 
 
@@ -38,7 +59,7 @@ def fetch(obj):
 
 
 if sys.argv[1] == "env":
-    dev.create_dependencies(sys.argv[2])
+    create_dependencies(sys.argv[2])
     if sys.argv[2] == "":
         print("Please provide a name for the environment")
 # else:
