@@ -1,19 +1,6 @@
+from dev import *
 import os
 
-def makefile(name, contents):
-    """
-
-    ### makefile
-
-
-
-    ` makefile(name='example_fie', contents='hello world, this is a file' ) `
-    """
-    with open(f"{name}", 'r') as f:
-        f.write(f"""{contents}""")
-
-
-
 
 def prompt():
     prompt = True
